/****************************************************************************
** Meta object code from reading C++ file 'kiriki.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiriki-17.08.3/src/kiriki.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kiriki.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_kiriki_t {
    QByteArrayData data[14];
    char stringdata0[124];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_kiriki_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_kiriki_t qt_meta_stringdata_kiriki = {
    {
QT_MOC_LITERAL(0, 0, 6), // "kiriki"
QT_MOC_LITERAL(1, 7, 11), // "demoStarted"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 1), // "t"
QT_MOC_LITERAL(4, 22, 7), // "newGame"
QT_MOC_LITERAL(5, 30, 4), // "demo"
QT_MOC_LITERAL(6, 35, 7), // "pressed"
QT_MOC_LITERAL(7, 43, 5), // "index"
QT_MOC_LITERAL(8, 49, 14), // "showHighScores"
QT_MOC_LITERAL(9, 64, 15), // "showPreferences"
QT_MOC_LITERAL(10, 80, 5), // "print"
QT_MOC_LITERAL(11, 86, 12), // "playComputer"
QT_MOC_LITERAL(12, 99, 8), // "showHint"
QT_MOC_LITERAL(13, 108, 15) // "settingsChanged"

    },
    "kiriki\0demoStarted\0\0t\0newGame\0demo\0"
    "pressed\0index\0showHighScores\0"
    "showPreferences\0print\0playComputer\0"
    "showHint\0settingsChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_kiriki[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       1,    0,   72,    2, 0x26 /* Public | MethodCloned */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   73,    2, 0x08 /* Private */,
       5,    0,   74,    2, 0x08 /* Private */,
       6,    1,   75,    2, 0x08 /* Private */,
       8,    0,   78,    2, 0x08 /* Private */,
       9,    0,   79,    2, 0x08 /* Private */,
      10,    0,   80,    2, 0x08 /* Private */,
      11,    0,   81,    2, 0x08 /* Private */,
      12,    0,   82,    2, 0x08 /* Private */,
      13,    0,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void kiriki::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        kiriki *_t = static_cast<kiriki *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->demoStarted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->demoStarted(); break;
        case 2: _t->newGame(); break;
        case 3: _t->demo(); break;
        case 4: _t->pressed((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 5: _t->showHighScores(); break;
        case 6: _t->showPreferences(); break;
        case 7: _t->print(); break;
        case 8: _t->playComputer(); break;
        case 9: _t->showHint(); break;
        case 10: _t->settingsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (kiriki::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&kiriki::demoStarted)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject kiriki::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_kiriki.data,
      qt_meta_data_kiriki,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *kiriki::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kiriki::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_kiriki.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int kiriki::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void kiriki::demoStarted(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
